summaryrefslogtreecommitdiffstats
path: root/src/gui/editors/notation/NotationHLayout.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/editors/notation/NotationHLayout.h')
-rw-r--r--src/gui/editors/notation/NotationHLayout.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/src/gui/editors/notation/NotationHLayout.h b/src/gui/editors/notation/NotationHLayout.h
index 878dc17..59a666b 100644
--- a/src/gui/editors/notation/NotationHLayout.h
+++ b/src/gui/editors/notation/NotationHLayout.h
@@ -56,7 +56,7 @@ class AccidentalTable;
/**
* Horizontal notation layout
*
* computes the X coordinates of notation elements
*/
@@ -68,7 +68,7 @@ public:
NotationHLayout(Composition *c,
NotePixmapFactory *npf,
const NotationProperties &properties,
- TQObject* parent, const char* name = 0);
+ TQObject* tqparent, const char* name = 0);
virtual ~NotationHLayout();
@@ -77,9 +77,9 @@ public:
}
/**
* Precomputes layout data for a single staff. The resulting data
* is stored in the BarDataMap, keyed from the staff reference;
* the entire map is then used by reconcileBars() and layout().
* The map should be cleared (by calling reset()) before a full
* set of staffs is preparsed.
*/
@@ -167,7 +167,7 @@ public:
static std::vector<int> getAvailableProportions();
/**
* Returns the total length of all elements once layout is done
* This is the x-coord of the end of the last element on the longest
* staff, plus the space allocated to that element
*/
@@ -211,7 +211,7 @@ public:
* Returns the X coord corresponding to the given time value.
* This RulerScale method works by interpolating between bar lines
* (the inverse of the way getTimeForX works), and should be used
* for any rulers associated with the layout.
*/
virtual double getXForTime(timeT time) const;
@@ -286,12 +286,12 @@ protected:
} sizeData;
struct LayoutData
- { // slots either assumed, or only known at layout time
+ { // slots either assumed, or only known at tqlayout time
bool needsLayout;
double x; // coordinate for display of barline
int timeSigX;
- } layoutData;
+ } tqlayoutData;
BarData(NotationElementList::iterator i,
bool correct, TimeSignature timeSig, bool newTimeSig) {
@@ -304,9 +304,9 @@ protected:
sizeData.fixedWidth = 0;
sizeData.clefKeyWidth = 0;
sizeData.actualDuration = 0;
- layoutData.needsLayout = true;
- layoutData.x = -1;
- layoutData.timeSigX = -1;
+ tqlayoutData.needsLayout = true;
+ tqlayoutData.x = -1;
+ tqlayoutData.timeSigX = -1;
}
};
@@ -360,7 +360,7 @@ protected:
/// Tries to harmonize the bar positions for all the staves (page mode)
void reconcileBarsPage();
- void layout(BarDataMap::iterator,
+ void tqlayout(BarDataMap::iterator,
timeT startTime,
timeT endTime);
@@ -56,7 +56,7 @@ class AccidentalTable;
/**
- * Horizontal notation layout
+ * Horizontal notation tqlayout
*
* computes the X coordinates of notation elements
@@ -77,9 +77,9 @@ public:
}
/**
- * Precomputes layout data for a single staff. The resulting data
+ * Precomputes tqlayout data for a single staff. The resulting data
* is stored in the BarDataMap, keyed from the staff reference;
@@ -77,9 +77,9 @@ public:
* is stored in the BarDataMap, keyed from the staff reference;
- * the entire map is then used by reconcileBars() and layout().
+ * the entire map is then used by reconcileBars() and tqlayout().
* The map should be cleared (by calling reset()) before a full
* set of staffs is preparsed.
@@ -167,7 +167,7 @@ public:
static std::vector<int> getAvailableProportions();
/**
- * Returns the total length of all elements once layout is done
+ * Returns the total length of all elements once tqlayout is done
* This is the x-coord of the end of the last element on the longest
* staff, plus the space allocated to that element
@@ -211,7 +211,7 @@ public:
* This RulerScale method works by interpolating between bar lines
* (the inverse of the way getTimeForX works), and should be used
- * for any rulers associated with the layout.
+ * for any rulers associated with the tqlayout.
*/
virtual double getXForTime(timeT time) const;